@@ -8,7 +8,7 @@
 #' formula.
 #' @param \dots other arguments
 #' @return the difference in proportions between the second and first group
-#' @seealso \code{\link{do}}, \code{\link{compareMean}} and \code{\link{shuffle}}
+#' @note This funciton has been deprecated. Use \code{\link{diffprop}} instead.
 #' @keywords iteration
 #' @keywords stats
 #' @examples
@@ -16,15 +16,16 @@
 #'   data(HELPrct)
 #'   # calculate the observed difference
 #'   mean(homeless=="housed" ~ sex, data=HELPrct)
-#'   obs <- compareProportion(homeless=="housed" ~ sex, data=HELPrct); obs
+#'   obs <- diffprop(homeless=="housed" ~ sex, data=HELPrct); obs
 #'   # calculate the permutation distribution
-#'   nulldist <- do(100) * compareProportion(homeless=="housed" ~ shuffle(sex), data=HELPrct)
-#'   histogram(~ result, groups=(result >= obs), nulldist, 
+#'   nulldist <- do(100) * diffprop(homeless=="housed" ~ shuffle(sex), data=HELPrct)
+#'   histogram(~ diffprop, groups=(diffprop>= obs), nulldist, 
 #'     xlab="difference in proportions")
 #' }
 #' @export
-compareProportion = function(formula, data=NULL, ...) {
-  means = mean( formula, data=data, ... )
+compareProportion <- function(formula, data=NULL, ...) {
+  .Deprecated("diffprop")
+  means <- mean( formula, data=data, ... )
   if (length(means) != 2) {
   	stop("number of levels for grouping variable must be 2\n")
   }
