@@ -236,7 +236,7 @@ mMap <- function(data, default = 'map',
               color = manipulate::picker(snames, initial="none ", label="Color"),
               facet = manipulate::picker(cnames, initial="none ", label="Facets"),
               projection = manipulate::picker(pnames, initial="mercator", label="Projection"),
-              key = manipulate::picker(lnames, label="key", initial=keyDefault)
+              key = manipulate::picker(lnames, label="Key", initial=keyDefault)
   )
 }
 
@@ -329,7 +329,7 @@ mScatter <- function(data, default = c('scatter','jitter','boxplot','violin','li
     stop("data must have at least 2 variables, at least one of which is quantitative")
   }
   cnames <- .NAprepend(variables$c)
-  mnames <- list("none", linear="linear", "smooth")
+  mnames <- list("none", linear="linear", "smooth", "spline")
   lnames <- list("none","top","right","left",
                  "N (lattice)" = "N", "NE (lattice)" = "NE", 
                  "E (lattice)" = "E", "SE (lattice)" = "SE", 
@@ -343,20 +343,18 @@ mScatter <- function(data, default = c('scatter','jitter','boxplot','violin','li
              system = manipulate::picker(sysnames, initial=system, label="Graphics System"),
              plotType = manipulate::picker(plotnames, initial=default, label="Type of plot      "),
              x = if (length(variables$q) >= 2) 
-               manipulate::picker(variables$all, initial=variables$q[[2]], label="any variable (x)   ")
+               manipulate::picker(variables$all, initial=variables$q[[2]], label="   Any variable (x)   ")
              else 
-               manipulate::picker(variables$all, initial=variables$c[[1]], label="any variable (x)   ")
+               manipulate::picker(variables$all, initial=variables$c[[1]], label="   Any variable (x)   ")
                ,
-             y = manipulate::picker(variables$q, initial=variables$q[[1]],   label="quant. variable (y)"),
-             flipCoords = manipulate::checkbox(label="Flip coordinates"),
+             y = manipulate::picker(variables$q, initial=variables$q[[1]],   label="   Quant. variable (y)"),
              color = manipulate::picker(snames, initial="none ", label="Color"),
-             size = manipulate::picker(snames, initial="none ", label="Size (ggplot only)"),
              facet = manipulate::picker(cnames, initial="none ", label="Facets"),
+             model = manipulate::picker(mnames, initial="none", label="Model"),
+             key = manipulate::picker(lnames, label="Key", initial=keyDefault),
+             size = manipulate::picker(snames, initial="none ", label="Size (ggplot only)"),
              logScales = manipulate::picker(list("none","x","y","both"), initial="none", label="log scales"),
-#             logx = manipulate::checkbox(label="log x-axis"),
-#             logy = manipulate::checkbox(label="log y-axis"),
-             key = manipulate::picker(lnames, label="key", initial=keyDefault),
-             model = manipulate::picker(mnames, initial="none", label="Model")
+             flipCoords = manipulate::checkbox(label="Flip coordinates")
   )
 }
 
@@ -404,6 +402,7 @@ mScatter <- function(data, default = c('scatter','jitter','boxplot','violin','li
 	  if (s$logy) res <- paste(res, " + scale_y_log10()", sep="")
 	  if (!is.null(s$facet) && !is.na(s$facet)) # why do I need both?
 		res<-paste(res, " + facet_wrap(~", s$facet, ", ncol=4)", sep="")
+	  if (s$model=="spline") res <- paste(res, " + stat_spline()")
 	  if (s$model=="linear") res <- paste(res, " + stat_smooth(method=lm)")
 	  if (s$model=="smooth") res <- paste(res, " + stat_smooth(method=loess)") 
     if (s$key %in% c('none','top','bottom','left','right')) {
@@ -433,7 +432,7 @@ mScatter <- function(data, default = c('scatter','jitter','boxplot','violin','li
     if (s$plotType == "jitter") {
       res <- paste(res, ', jitter.x=TRUE, jitter.y=TRUE', sep="")
     }
-    if (s$plotType == "line" && ! s$model %in% c("linear", "smooth")) {
+    if (s$plotType == "line" && ! s$model %in% c("linear", "smooth", "spline")) {
       res <- paste(res, ', type="l"', sep="")
     }
     scales <- character(0)
@@ -448,8 +447,10 @@ mScatter <- function(data, default = c('scatter','jitter','boxplot','violin','li
 	  }
 	  if (s$model=="linear")
 	    res <- paste(res, if (s$plotType == "line") ', type=c("l","r")' else ', type=c("p","r")', sep ="")
-	  if (s$model=="smooth")
-	    res <- paste(res, if (s$plotType == "line") ', type=c("l","smooth")' else ', type=c("p","smooth")', sep ="")
+	  if (s$model %in% c("smooth", "spline")) {
+	    pt <- if (s$plotType == "line") "l" else "p"
+	    res <- paste0(res, ', type=c("', pt, '", "', s$model, '")')
+	  }
 	  if (s$key %in% c('top','bottom','left','right')) {
 	    res <- paste(res, 
 	                 ', auto.key=list(space="', s$key, '"',
@@ -520,7 +521,7 @@ mUniplot <- function(data, default=c('histogram','density', 'frequency polygon',
               facet = manipulate::picker(cnames, initial="none ", label="Facets"),
 #              logx = manipulate::checkbox(label="log x-axis"),
 #              logy = manipulate::checkbox(label="log y-axis"),
-              key = manipulate::picker(lnames, label="key", initial=keyDefault)
+              key = manipulate::picker(lnames, label="Key", initial=keyDefault)
   )
 }
 
