@@ -1,14 +1,13 @@
 #' Augmented histograms
 #' 
 #' The \pkg{mosaic} package adds some additional functionality to 
-#' \code{\link[lattice]{histogram}}, making it simpler to obtain certain common 
+#' \code{\link[lattice]{histogram}()}, making it simpler to obtain certain common 
 #' histogram adornments.  This is done be resetting the default panel
 #' and prepanel functions used by histogram.
 #' 
 #' @rdname xhistogram
 #' @aliases histogram
 #' @param x a formula or a numeric vector
-#' @param data a data frame in which to evaluate \code{x}
 #' @param panel a panel function
 #' @param type one of \code{'density'}, \code{'count'}, or \code{'percent'}
 #' @param nint approximate number of bins
@@ -16,26 +15,37 @@
 #'        or a method \code{\link{hist}} knows about given as a character string.
 #'        When using the \pkg{mosaic} package defaults, 
 #'        \code{\link[mosaic]{xhistogramBreaks}} is used.
-#' @param \dots additional arguments passed to \code{\link[lattice]{histogram}} 
-#' and (by default when the \pkg{mosaic} package has been loaded) on to 
+#' @param \dots additional arguments passed from \code{\link[lattice]{histogram}} 
+#' to the panel function; by default when the \pkg{mosaic} package has been loaded this will
 #' \code{\link{panel.xhistogram}}.
 #'
-#' @seealso \code{\link[lattice]{histogram}}
-#' @note The use of \code{xhistogram} has been deprecated.  Versions of 
-#' \pkg{lattice} since 0.20-21 support setting custom defaults 
+#' @seealso \code{\link[lattice]{histogram}}, \code{\link{mosaicLatticeOptions}()},
+#' and \code{\link{restoreLatticeOptions}()}.
+#' 
+#' @note Versions of \pkg{lattice} since 0.20-21 support setting custom defaults 
 #' for \code{breaks}, \code{panel}, and \code{prepanel} used by 
-#' \code{histogram}, so \code{xhistogram} is no longer needed.  \code{xhistogram} will
-#' be retained temporarily to support users with older versions of \pkg{lattice}.
+#' \code{histogram()}, so \code{xhistogram()} is no longer needed.  
+#' As a result, \code{xhistogram()} 
+#' (which was required in earlier versions of \pkg{mosaic}
+#' is no longer needed and has been removed.
+#' 
+#' @details
+#' The primary additional functionality added to \code{\link{histogram}()}
+#' are the arguments \code{width} and \code{center} which provide a simple
+#' way of describing equal-sized bins, and \code{fit} which can be used to
+#' overlay the density curve for one of several distributions.  The
+#' \code{groups} argument can be used to color the bins.  The primary use
+#' for this is to shade tails of histograms, but there may be other uses
+#' as well.
 #'
 #' @export
 
-xhistogram <- function (x, data=NULL, panel=panel.xhistogram, type='density', 
-                                      center=NULL, width=NULL, ...) {
-   .Deprecated("histogram")
-   histogram(x, data=data, panel=panel, type=type, center=center, 
-             width=width, ...)
+xhistogram <- function (...) { # x, data=NULL, panel=panel.xhistogram, type='density', 
+                               #       center=NULL, width=NULL, ...) {
+   .Defunct(msg = "xhistogram() is no longer needed; simply use histogram() with the mosaic package attached.")
 }
 
+
 #' @rdname xhistogram
 #' @return \code{xhistogramBreaks} returns a vector of break points
 #' @examples
@@ -181,7 +191,7 @@ function (x,
     }
   } 
   if (is.null(args)) {
-    args = list(mean = mean(x, na.rm = T), sd = sd(x, na.rm = T))
+    args = list(mean = base::mean(x, na.rm = TRUE), sd = stats::sd(x, na.rm = TRUE))
   }
   
   ###  done cleaining up args; away we go
